# Color Differences Analyzer

[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![Test](https://github.com/leynier/color-differences-analyzer/workflows/CI/badge.svg)](https://github.com/leynier/color-differences-analyzer/actions?query=workflow%3ACI)
[![codecov](https://codecov.io/gh/leynier/color-differences-analyzer/branch/main/graph/badge.svg?token=Z1MEEL3EAB)](https://codecov.io/gh/leynier/color-differences-analyzer)
[![DeepSource](https://deepsource.io/gh/leynier/color-differences-analyzer.svg/?label=active+issues)](https://deepsource.io/gh/leynier/color-differences-analyzer/?ref=repository-badge)
[![Version](https://img.shields.io/pypi/v/color-differences-analyzer?color=%2334D058&label=Version)](https://pypi.org/project/color-differences-analyzer)
[![Last commit](https://img.shields.io/github/last-commit/leynier/color-differences-analyzer.svg?style=flat)](https://github.com/leynier/color-differences-analyzer/commits)
[![GitHub commit activity](https://img.shields.io/github/commit-activity/m/leynier/color-differences-analyzer)](https://github.com/leynier/color-differences-analyzer/commits)
[![Github Stars](https://img.shields.io/github/stars/leynier/color-differences-analyzer?style=flat&logo=github)](https://github.com/leynier/color-differences-analyzer/stargazers)
[![Github Forks](https://img.shields.io/github/forks/leynier/color-differences-analyzer?style=flat&logo=github)](https://github.com/leynier/color-differences-analyzer/network/members)
[![Github Watchers](https://img.shields.io/github/watchers/leynier/color-differences-analyzer?style=flat&logo=github)](https://github.com/leynier/color-differences-analyzer)
[![Website](https://img.shields.io/website?up_message=online&url=https%3A%2F%2Fleynier.github.io/color-differences-analyzer)](https://leynier.github.io/color-differences-analyzer)
[![GitHub contributors](https://img.shields.io/github/contributors/leynier/color-differences-analyzer)](https://github.com/leynier/color-differences-analyzer/graphs/contributors)

Command line interface to analyze differences of colors from images implemented with Python.
